@@ -59,6 +59,8 @@ class UIElement:
         self._stop_x,   self._start_y   = 0, 0
         self._height,   self._width     = 0, 0
         self._color                     = py_cui.WHITE_ON_BLACK
+        self._border_color              = self._color
+        self._selected_color            = self._color
         self._mouse_press_handler       = None
         self._selected                  = False
         self._renderer                  = renderer
@@ -118,7 +120,7 @@ class UIElement:
 
     def get_id(self):
         """Gets the element ID
-        
+
         Returns
         -------
         id : int
@@ -130,7 +132,7 @@ class UIElement:
 
     def get_title(self):
         """Getter for ui element title
-        
+
         Returns
         -------
         title : str
@@ -142,7 +144,7 @@ class UIElement:
 
     def get_padding(self):
         """Gets ui element padding on in characters
-        
+
         Returns
         -------
         padx, pady : int, int
@@ -166,7 +168,7 @@ class UIElement:
 
     def get_stop_position(self):
         """Gets coords of lower right corner
-        
+
         Returns
         -------
         stop_x, stop_y : int, int
@@ -188,6 +190,30 @@ class UIElement:
         return self._color
 
 
+    def get_border_color(self):
+        """Gets current element border color
+
+        Returns
+        -------
+        color : int
+            color code for combination
+        """
+
+        return self._border_color
+
+
+    def get_selected_color(self):
+        """Gets current selected item color
+
+        Returns
+        -------
+        color : int
+            color code for combination
+        """
+
+        return self._selected_color
+
+
     def is_selected(self):
         """Get selected status
 
@@ -245,9 +271,37 @@ class UIElement:
             New color pair key code
         """
 
+        if self._border_color == self._color:
+            self._border_color = color
+        if self._selected_color == self._color:
+            self._selected_color = color
         self._color = color
 
 
+    def set_border_color(self, color):
+        """Sets element border color
+
+        Parameters
+        ----------
+        color : int
+            New color pair key code
+        """
+
+        self._border_color = color
+
+
+    def set_selected_color(self, color):
+        """Sets element sected color
+
+        Parameters
+        ----------
+        color : int
+            New color pair key code
+        """
+
+        self._selected_color = color
+
+
     def set_selected(self, selected):
         """Marks the UI element as selected or not selected
 
@@ -366,7 +420,7 @@ class UIElement:
         within_x = self._start_x <= x and self._start_x + self._width >= x
         within_y = self._start_y <= y and self._start_y + self._height >= y
         return within_x and within_y
-        
+
 
 
 class UIImplementation:
@@ -438,7 +492,7 @@ class TextBoxImplementation(UIImplementation):
 
     def get_cursor_text_pos(self):
         """Gets current position of cursor relative to text
-        
+
         Returns
         -------
         cursor_text_pos : int
@@ -624,7 +678,7 @@ class MenuImplementation(UIImplementation):
         self._selected_item = 0
         self._top_view = 0
 
-        self._logger.debug('Clearing menu')
+        self._logger.info('Clearing menu')
 
 
 
@@ -661,7 +715,7 @@ class MenuImplementation(UIImplementation):
         if self._selected_item > 0:
             self._selected_item = self._selected_item - 1
 
-        self._logger.debug('Scrolling up to item {}'.format(self._selected_item))
+        self._logger.info('Scrolling up to item {}'.format(self._selected_item))
 
 
     def _scroll_down(self, viewport_height):
@@ -680,7 +734,7 @@ class MenuImplementation(UIImplementation):
         if self._selected_item > self._top_view + viewport_height:
             self._top_view = self._top_view + 1
 
-        self._logger.debug('Scrolling down to item {}'.format(self._selected_item))
+        self._logger.info('Scrolling down to item {}'.format(self._selected_item))
 
 
     def _jump_up(self):
@@ -736,7 +790,7 @@ class MenuImplementation(UIImplementation):
             Object to add to the menu. Must have implemented __str__ function
         """
 
-        self._logger.debug('Adding item {} to menu'.format(str(item)))
+        self._logger.info('Adding item {} to menu'.format(str(item)))
         self._view_items.append(item)
 
 
@@ -749,7 +803,7 @@ class MenuImplementation(UIImplementation):
             list of objects to add as items to the scrollmenu
         """
 
-        self._logger.debug('Adding item list {} to menu'.format(str(item_list)))
+        self._logger.info('Adding item list {} to menu'.format(str(item_list)))
         for item in item_list:
             self.add_item(item)
 
@@ -760,7 +814,7 @@ class MenuImplementation(UIImplementation):
 
         if len(self._view_items) == 0:
             return
-        self._logger.debug('Removing {}'.format(str(self._view_items[self._selected_item])))
+        self._logger.info('Removing {}'.format(str(self._view_items[self._selected_item])))
         del self._view_items[self._selected_item]
         if self._selected_item >= len(self._view_items) and self._selected_item > 0:
             self._selected_item = self._selected_item - 1
@@ -777,7 +831,7 @@ class MenuImplementation(UIImplementation):
 
         if len(self._view_items) == 0 or item not in self._view_items:
             return
-        self._logger.debug('Removing {}'.format(str(item)))
+        self._logger.info('Removing {}'.format(str(item)))
         i_index = self._view_items.index(item)
         del self._view_items[i_index]
         if self._selected_item >= i_index:
@@ -812,7 +866,7 @@ class MenuImplementation(UIImplementation):
 
 class CheckBoxMenuImplementation(MenuImplementation):
     """Class representing checkbox menu ui implementation
-    
+
     Attributes
     ----------
     _selected_item_dict : dict of object -> bool
@@ -832,7 +886,7 @@ class CheckBoxMenuImplementation(MenuImplementation):
 
     def add_item(self, item):
         """Extends base class function, item is added and marked as unchecked to start
-        
+
         Parameters
         ----------
         item : object
@@ -878,7 +932,7 @@ class CheckBoxMenuImplementation(MenuImplementation):
 
 class TextBlockImplementation(UIImplementation):
     """Base class for TextBlockImplementation
-    
+
     Contains all logic required for a textblock ui element to function.
     Currently only implemented in widget form, though popup form is possible.
 
@@ -1041,7 +1095,7 @@ class TextBlockImplementation(UIImplementation):
         self._cursor_text_pos_y = 0
         self._text_lines = []
         self._text_lines.append('')
-        self._logger.debug('Cleared textblock')
+        self._logger.info('Cleared textblock')
 
 
     def get_current_line(self):
@@ -1103,7 +1157,7 @@ class TextBlockImplementation(UIImplementation):
                 self._viewport_x_start = self._viewport_x_start - 1
             self._cursor_text_pos_x = self._cursor_text_pos_x - 1
 
-        self._logger.debug('Moved cursor left to pos {}'.format(self._cursor_text_pos_x))
+        self._logger.info('Moved cursor left to pos {}'.format(self._cursor_text_pos_x))
 
 
     def _move_right(self):
@@ -1119,7 +1173,7 @@ class TextBlockImplementation(UIImplementation):
                 self._viewport_x_start = self._viewport_x_start + 1
             self._cursor_text_pos_x = self._cursor_text_pos_x + 1
 
-        self._logger.debug('Moved cursor right to pos {}'.format(self._cursor_text_pos_x))
+        self._logger.info('Moved cursor right to pos {}'.format(self._cursor_text_pos_x))
 
 
     def _move_up(self):
@@ -1138,13 +1192,13 @@ class TextBlockImplementation(UIImplementation):
                 self._cursor_x = self._cursor_x - (self._cursor_text_pos_x - temp)
                 self._cursor_text_pos_x = temp
 
-        self._logger.debug('Moved cursor up to line {}'.format(self._cursor_text_pos_y))
+        self._logger.info('Moved cursor up to line {}'.format(self._cursor_text_pos_y))
 
 
     def _move_down(self):
         """Function that moves the cursor/text position one location down
         """
-        
+
         if self._cursor_text_pos_y < len(self._text_lines) - 1:
             if self._cursor_y < self._cursor_max_down:
                 self._cursor_y = self._cursor_y + 1
@@ -1155,8 +1209,8 @@ class TextBlockImplementation(UIImplementation):
                 temp = len(self._text_lines[self._cursor_text_pos_y])
                 self._cursor_x = self._cursor_x - (self._cursor_text_pos_x - temp)
                 self._cursor_text_pos_x = temp
-        
-        self._logger.debug('Moved cursor down to line {}'.format(self._cursor_text_pos_y))
+
+        self._logger.info('Moved cursor down to line {}'.format(self._cursor_text_pos_y))
 
 
 
@@ -1165,7 +1219,7 @@ class TextBlockImplementation(UIImplementation):
         """
 
         current_line = self.get_current_line()
-        self._logger.debug('Inserting newline in location {}'.format(self._cursor_text_pos_x))
+        self._logger.info('Inserting newline in location {}'.format(self._cursor_text_pos_x))
 
         new_line_1 = current_line[:self._cursor_text_pos_x]
         new_line_2 = current_line[self._cursor_text_pos_x:]
@@ -1186,7 +1240,7 @@ class TextBlockImplementation(UIImplementation):
         """
 
         current_line = self.get_current_line()
-        self._logger.debug('Inserting backspace in location {}'.format(self._cursor_text_pos_x))
+        self._logger.info('Inserting backspace in location {}'.format(self._cursor_text_pos_x))
 
         if self._cursor_text_pos_x == 0 and self._cursor_text_pos_y != 0:
             self._cursor_text_pos_x = len(self._text_lines[self._cursor_text_pos_y - 1])
@@ -1209,7 +1263,7 @@ class TextBlockImplementation(UIImplementation):
         """Function that handles recieving a home keypress
         """
 
-        self._logger.debug('Inserting Home')
+        self._logger.info('Inserting Home')
 
         self._cursor_x = self._cursor_max_left
         self._cursor_text_pos_x = 0
@@ -1221,7 +1275,7 @@ class TextBlockImplementation(UIImplementation):
         """
 
         current_line = self.get_current_line()
-        self._logger.debug('Inserting End')
+        self._logger.info('Inserting End')
 
         self._cursor_text_pos_x = len(current_line)
         if len(current_line) > self._viewport_width:
@@ -1236,7 +1290,7 @@ class TextBlockImplementation(UIImplementation):
         """
 
         current_line = self.get_current_line()
-        self._logger.debug('Inserting delete to pos {}'.format(self._cursor_text_pos_x))
+        self._logger.info('Inserting delete to pos {}'.format(self._cursor_text_pos_x))
 
         if self._cursor_text_pos_x == len(current_line) and self._cursor_text_pos_y < len(self._text_lines) - 1:
             self._text_lines[self._cursor_text_pos_y] = self._text_lines[self._cursor_text_pos_y] + self._text_lines[self._cursor_text_pos_y + 1]
@@ -1255,11 +1309,11 @@ class TextBlockImplementation(UIImplementation):
         """
 
         current_line = self.get_current_line()
-        self._logger.debug('Inserting character {} to pos {}'.format(chr(key_pressed), self._cursor_text_pos_x))
+        self._logger.info('Inserting character {} to pos {}'.format(chr(key_pressed), self._cursor_text_pos_x))
 
         self.set_text_line(current_line[:self._cursor_text_pos_x] + chr(key_pressed) + current_line[self._cursor_text_pos_x:])
         if len(current_line) <= self._viewport_width:
             self._cursor_x = self._cursor_x + 1
         elif self._viewport_x_start + self._viewport_width < len(current_line):
             self._viewport_x_start = self._viewport_x_start + 1
-        self._cursor_text_pos_x = self._cursor_text_pos_x + 1
\ No newline at end of file
+        self._cursor_text_pos_x = self._cursor_text_pos_x + 1
