@@ -1,7 +1,7 @@
-"""File contatining all core widget classes for py_cui.
+"""Module contatining all core widget classes for py_cui.
 
 Widgets are the basic building blocks of a user interface made with py_cui.
-This file contains classes for:
+This module contains classes for:
 
 * Base Widget class
 * Label
@@ -11,8 +11,9 @@ This file contains classes for:
 * Button
 * TextBox
 * Text Block
+* Slider
 
-Additional widgets should be added in as additional_widgets/$WIDGET_NAME.py, importing this
+Additional widgets should be added in appropriate sub-modules, importing this
 file and extending the base Widget class, or if appropriate one of the other core widgets.
 """
 
@@ -59,12 +60,12 @@ class Widget(py_cui.ui.UIElement):
         super().__init__(id, title, None, logger)
         if grid is None:
             raise py_cui.errors.PyCUIMissingParentError("Cannot add widget to NoneType")
-        
+
         self._grid = grid
         grid_rows, grid_cols = self._grid.get_dimensions()
         if (grid_cols < column + column_span) or (grid_rows < row + row_span):
             raise py_cui.errors.PyCUIOutOfBoundsError("Target grid too small for widget {}".format(title))
-        
+
         self._row          = row
         self._column       = column
         self._row_span     = row_span
@@ -74,6 +75,8 @@ class Widget(py_cui.ui.UIElement):
         self._selectable       = selectable
         self._key_commands     = {}
         self._text_color_rules = []
+        self._default_color = py_cui.WHITE_ON_BLACK
+        self._border_color = self._default_color
         self.update_height_width()
 
 
@@ -106,7 +109,7 @@ class Widget(py_cui.ui.UIElement):
             self.add_key_command(key, command)
 
 
-    def add_text_color_rule(self, regex, color, rule_type, match_type='line', region=[0,1], include_whitespace=False):
+    def add_text_color_rule(self, regex, color, rule_type, match_type='line', region=[0,1], include_whitespace=False, selected_color=None):
         """Forces renderer to draw text using given color if text_condition_function returns True
 
         Parameters
@@ -125,7 +128,11 @@ class Widget(py_cui.ui.UIElement):
             if false, strip string before checking for match
         """
 
-        new_color_rule = py_cui.colors.ColorRule(regex, color, rule_type, match_type, region, include_whitespace, self._logger)
+        selected = color
+        if selected_color is not None:
+            selected = selected_color
+
+        new_color_rule = py_cui.colors.ColorRule(regex, color, selected, rule_type, match_type, region, include_whitespace, self._logger)
         self._text_color_rules.append(new_color_rule)
 
 
@@ -142,7 +149,7 @@ class Widget(py_cui.ui.UIElement):
         y_adjust                = self._row
         offset_x, offset_y      = self._grid.get_offsets()
         row_height, col_width   = self._grid.get_cell_dimensions()
-        
+
         if self._column > offset_x:
             x_adjust = offset_x
         if self._row > offset_y:
@@ -168,17 +175,17 @@ class Widget(py_cui.ui.UIElement):
 
         width   = col_width     * self._column_span
         height  = row_height    * self._row_span
-        
+
         counter = self._row
         while counter < offset_y and (counter - self._row) < self._row_span:
             height  = height    + 1
             counter = counter   + 1
-        
+
         counter = self._column
         while counter < offset_x and (counter - self._column) < self._column_span:
             width   = width     + 1
             counter = counter   + 1
-        
+
         return width + self._start_x, height + self._start_y
 
 
@@ -206,6 +213,18 @@ class Widget(py_cui.ui.UIElement):
         return self._row_span, self._column_span
 
 
+    def set_selectable(self, selectable):
+        """Setter for widget selectablility
+
+        Paramters
+        ---------
+        selectable : bool
+            Widget selectable if true, otherwise not
+        """
+
+        self._selectable = selectable
+
+
     def is_selectable(self):
         """Checks if the widget is selectable
 
@@ -336,6 +355,19 @@ class BlockLabel(Widget):
         self._draw_border  = False
 
 
+    def set_title(self, title):
+        """Override of base class, splits title into lines for rendering line by line.
+
+        Parameters
+        ----------
+        title : str
+            The new title for the block label object.
+        """
+
+        self._title = title
+        self._lines = title.splitlines()
+
+
     def toggle_border(self):
         """Function that gives option to draw border around label
         """
@@ -416,7 +448,7 @@ class ScrollMenu(Widget, py_cui.ui.MenuImplementation):
             self._jump_up()
         if key_pressed == py_cui.keys.KEY_PAGE_DOWN:
             self._jump_down(viewport_height)
-        
+
 
 
     def _draw(self):
@@ -690,7 +722,7 @@ class TextBox(Widget, py_cui.ui.TextBoxImplementation):
         if self._password:
             temp = '*' * len(render_text)
             render_text = temp
-            
+
         self._renderer.draw_text(self, render_text, self._cursor_y, selected=self._selected)
         if self._selected:
             self._renderer.draw_cursor(self._cursor_y, self._cursor_x)
@@ -740,18 +772,20 @@ class ScrollTextBlock(Widget, py_cui.ui.TextBlockImplementation):
         x, y : int
             Coordinates of mouse press
         """
-        
+
         super()._handle_mouse_press(x, y)
-        if y >= self._cursor_max_up and y <= self._cursor_max_down: 
+        if y >= self._cursor_max_up and y <= self._cursor_max_down:
             if x >= self._cursor_max_left and x <= self._cursor_max_right:
                 line_clicked_index = y - self._cursor_max_up + self._viewport_y_start
                 if len(self._text_lines) < line_clicked_index:
                     self._cursor_text_pos_y = len(self._text_lines)
                     self._cursor_y = self._cursor_max_up + self._cursor_text_pos_y - self._viewport_y_start
+                    line = self._text_lines[len(self._text_lines) - 1]
                 else:
                     self._cursor_text_pos_y = line_clicked_index
                     self._cursor_y = y
-                line = self._text_lines[line_clicked_index]
+                    line = self._text_lines[line_clicked_index]
+                
                 if x <= len(line) + self._cursor_max_left:
                     old_text_pos = self._cursor_text_pos_x
                     old_cursor_x = self._cursor_x
@@ -819,3 +853,5 @@ class ScrollTextBlock(Widget, py_cui.ui.TextBlockImplementation):
         else:
             self._renderer.reset_cursor(self)
         self._renderer.unset_color_mode(self._color)
+
+
